--
-- MowerBlades
-- Specialization for blades on drum mowers
--
-- @author  Stefan Maurus    
-- @date  2016/06/11

-- Copyright  Stefan Maurus, www.stefanmaurus.de

MowerBlades = {};

function MowerBlades.prerequisitesPresent(specializations)
    return true;
end;

function MowerBlades:load(savegame)
    local i = 0;
    self.mowerBlades = {};
    while true do
        local key = string.format("vehicle.mowerBlades.blade(%d)", i);
        if not hasXMLProperty(self.xmlFile, key) then
            break;
        end;
        
        local index = Utils.indexToObject(self.components, getXMLString(self.xmlFile, key.."#index"));
        
        local curve = AnimCurve:new(linearInterpolatorTransRotScale);
        
        local x, y, z = Utils.getVectorFromString(getXMLString(self.xmlFile,  key.."#startRotation"));
        curve:addKeyframe({x=0, y=0, z=0, rx=math.rad(x), ry=math.rad(y), rz=math.rad(z), sx=0, sy=0, sz=0, time = 0});
        
        local x, y, z = Utils.getVectorFromString(getXMLString(self.xmlFile,  key.."#centerRotation"));
        curve:addKeyframe({x=0, y=0, z=0, rx=math.rad(x), ry=math.rad(y), rz=math.rad(z), sx=0, sy=0, sz=0, time = 0.5});
        
        local x, y, z = Utils.getVectorFromString(getXMLString(self.xmlFile,  key.."#endRotation"));
        curve:addKeyframe({x=0, y=0, z=0, rx=math.rad(x), ry=math.rad(y), rz=math.rad(z), sx=0, sy=0, sz=0, time = 1});
        setRotation(index, math.rad(x), math.rad(y), math.rad(z));
        
        table.insert(self.mowerBlades, {index=index, curve=curve, start=true});
        i = i + 1;
    end;    
    
    self.bladeTime = 1;
end;

function MowerBlades:delete()
end;

function MowerBlades:mouseEvent(posX, posY, isDown, isUp, button)
end;

function MowerBlades:keyEvent(unicode, sym, modifier, isDown)
end;

function MowerBlades:update(dt)
    for i, v in pairs(self.mowerBlades) do
        if self:getIsTurnedOn() then
            if v.start then
                self.bladeTime = math.max(self.bladeTime - 0.01, 0);
                if self.bladeTime == 0 then
                    v.start = false;
                end;
            else
                self.bladeTime = math.min(self.bladeTime + 0.01, 0.5);
            end;
        else
            self.bladeTime = math.min(self.bladeTime + 0.0002, 1);
            v.start = true;
        end;

        local _,_,_, x, y, z,_,_,_ = v.curve:get(self.bladeTime);
        setRotation(v.index, x, y, z);        
    end;
end;

function MowerBlades:updateTick(dt)
end;

function MowerBlades:draw()
end;